# gen-trace
[![pytest](https://github.com/ffreemt/gen-trace/actions/workflows/routine-tests.yml/badge.svg)](https://github.com/ffreemt/gen-trace/actions)[![python](https://img.shields.io/static/v1?label=python+&message=3.8&color=blue)](https://www.python.org/downloads/)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/gen-trace.svg)](https://badge.fury.io/py/gen-trace)

Generate interpolate1d (trace) for a cmat

** for python 3.8 only ** (contact the dev concerning other python versions.)

## Install it

```shell
pip install gen-trace
# pip install git+https://github.com/ffreemt/gen-trace
# poetry add git+https://github.com/ffreemt/gen-trace
# git clone https://github.com/ffreemt/gen-trace && cd gen-trace
```

## Use it
```python
from gen_trace.cmat2aset import cmat2aset

```
